/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements. See the NOTICE
 * file distributed with this work for additional information regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.sosnoski.ws.library.cxf;

import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.xml.bind.JAXBElement;

/**
 * Interface for book server access as web service.
 */
@Path("")
@Produces("application/xml")
public interface LibraryRestInterface
{
    @GET
    @Path("books")
    BookList getAllBooks();

    @GET
    @Path("books/{isbn}")
    JAXBElement<BookInformation> getBook(@PathParam("isbn") String isbn);

    @PUT
    @Path("books")
    void addBook(JAXBElement<BookInformation> wrapper);

    @DELETE
    @Path("books/{isbn}")
    void deleteBook(@PathParam("isbn") String isbn);

    @GET
    @Path("types")
    TypeList getTypes();

    @GET
    @Path("types/{type}")
    BookList getBooksByType(@PathParam("type") String type);

    @PUT
    @Path("types")
    void addType(JAXBElement<TypeInformation> wrapper);
}